/*
 * ERIKA Enterprise Basic - a tiny RTOS for small microcontrollers
 *
 * Copyright (C) 2002-2007  Evidence Srl
 *
 * This file is part of ERIKA Enterprise Basic.
 *
 * ERIKA Enterprise Basic is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General Public License
 * version 2 as published by the Free Software Foundation.
 *
 * ERIKA Enterprise Basic is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License version 2 for more details.
 *
 * You should have received a copy of the GNU General Public License
 * version 2 along with ERIKA Enterprise Basic; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301 USA.
 */

/*
 * Author: Gianluca Franchino.
 * Affiliation: Retis Lab. Scuola Superiore Sant'Anna. Pisa (Italy).
 * Contacts: g.franchino@sssup.it; gianluca@evidence.eu.com
 * Date: 02/27/2008.
 * 
 */
 

#include "eeuart.h"
#include "ee_internal.h"
#include "ee_console.h"

#ifndef BYTE
#define BYTE EE_UINT8
#endif

#ifndef WORD
#define WORD EE_UINT16
#endif



BYTE console_port;


/*******************************************************************************
 * Function:        void ee_console_init(BYTE console_port)
 *
 * PreCondition:    None
 *
 * Input:           None
 *
 * Output:          none
 *
 * Side Effects:    None
 *
 * Overview:        This routine initializes the console.
 *                  
 * Note:            None
 ******************************************************************************/
 
void ee_console_init(BYTE port)
{ 	
	console_port = port;
	
	if (console_port == UART1)
  		EE_UART1_Init(115200, BIT8_NO | BIT_STOP_1, CTRL_SIMPLE);
  	else
  		EE_UART2_Init(115200, BIT8_NO | BIT_STOP_1, CTRL_SIMPLE);
  		
}

/*******************************************************************************
 * Function:        void ee_console_out(BYTE ch)
 *
 * PreCondition:    None
 *
 * Input:           the character to send out to the console.
 *
 * Output:          0 all right, -1 otherwise
 *
 * Side Effects:    None
 *
 * Overview:        This routine send a character to the console.
 *                  
 * Note:            None
 ******************************************************************************/
 
void ee_console_out(BYTE ch)
{
	if (console_port == UART1)
		EE_UART1_Send(ch);
	else
		EE_UART2_Send(ch);
}

/*******************************************************************************
 * Function:        void ee_console_out_str(const char *ch)
 *
 * PreCondition:    None
 *
 * Input:           the string to send out to the console.
 *
 * Output:          None
 *
 * Side Effects:    None
 *
 * Overview:        This routine send a string to the console.
 *                  
 * Note:            None
 ******************************************************************************/
 
void ee_console_out_str(const char *ch)
{

	while (*ch != '\0') {
		if (console_port == UART1)
			EE_UART1_Send(*ch++);
		else
			EE_UART2_Send(*ch++);
	}

}

