/*
 * File Name: hal.h
 * 
 * File Contents: a set of defines used to abstract the hardware (dsPIC33 + EasyBee)
 * from the application source code. This can be useful if we want to reuse 
 * the application code with different hardware platforms. 
 * 
 * This source code is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
 * 
 * Main documentation: 
 * <CC2420_Data_Sheet_1_3.pdf> The CC2420 datasheet. Available at www.ti.com
 * <EasyBeeDS480.pdf> EasyBee board datasheet. Available at www.rfsolutions.co.uk
 * <Flex_ref_man_027.pdf> Flex reference Manual. Available at www.evidence.eu.com 
 * <70286A.pdf> The dsPIC33 datasheet. Available at www.microchip.com
 * 
 * Further documentation on dsPIC33x can be found at www.microchip.com 
 * 
 * Author: Gianluca Franchino.
 * Affiliation: Retis Lab. Scuola Superiore Sant'Anna. Pisa (Italy).
 * Contacts: g.franchino@sssup.it; gianluca@evidence.eu.com
 * Date: 02/27/2008.
 * 
 */

#ifndef _HAL_H_
#define _HAL_H_

//#define FLEX_DEMO_BOARD

#define __CC2420__

#ifdef __CC2420__

#include "cc2420.h"


#ifndef FLEX_DEMO_BOARD

#define RESETn	PORTGbits.RG0
#define VREG_EN	PORTGbits.RG12
#define FIFO	PORTEbits.RE9
#define FIFOP	PORTFbits.RF6
#define CSn	PORTGbits.RG9

#define TRIS_RESETn	TRISGbits.TRISG0
#define TRIS_VREG_EN	TRISGbits.TRISG12
#define TRIS_FIFO	TRISEbits.TRISE9
#define TRIS_FIFOP	TRISFbits.TRISF6
#define TRIS_CSn	TRISGbits.TRISG9

#else

#define RESETn	PORTGbits.RG0
#define VREG_EN	PORTGbits.RG12
#define FIFO	PORTDbits.RD14
#define FIFOP	PORTAbits.RA15
#define CSn	PORTGbits.RG9

#define TRIS_RESETn	TRISGbits.TRISG0
#define TRIS_VREG_EN	TRISGbits.TRISG12
#define TRIS_FIFO	TRISDbits.TRISD14
#define TRIS_FIFOP	TRISAbits.TRISA15
#define TRIS_CSn	TRISGbits.TRISG9

#endif

extern void ee_console_init(BYTE console_port);
extern void ee_console_out(BYTE ch);
extern void ee_console_out_str(const char *ch);

extern void ee_radio_spi_init(BYTE spi_port);
extern BYTE ee_radio_spi_put(BYTE v);
extern BYTE ee_radio_spi_get(void);

extern int cc2420_init(void);
extern void cc2420_set_pa(BYTE);
extern BYTE cc2420_get_status(void);
extern int cc2420_get_fifo_msg(BYTE *);
extern int cc2420_rssi_get(void);
extern int cc2420_check(void);
extern BYTE cc2420_FSM_get(void);
extern void cc2420_store_msg(BYTE *, BYTE);
extern void cc2420_store_txfifo(BYTE*, BYTE);
extern void cc2420_set_tx(void);
extern BYTE cc2420_set_tx_on_cca();
extern void cc2420_set_rx(void);
extern void cc2420_set_sleep(int);
extern void cc2420_turn_on(void);
extern void cc2420_set_channel(BYTE );
extern void cc2420_set_short_mac_add(BYTE*);
extern void cc2420_set_ex_mac_add(BYTE*);
extern void cc2420_set_mac_pan_id(BYTE*);


#define	hal_console_init(a)  ee_console_init(a)
#define	hal_console_out(a) ee_console_out(a)
#define	hal_console_out_str(a) ee_console_out_str(a)
#define	hal_radio_spi_init(a) ee_radio_spi_init(a)
#define hal_radio_spi_put(a) ee_radio_spi_put(a)
#define hal_radio_spi_get()  ee_radio_spi_get()

#define hal_radio_init() cc2420_init()
#define hal_set_tx_power(a) cc2420_set_pa(a)
#define	hal_get_msg(a) cc2420_get_fifo_msg(a)
#define hal_store_msg(a,b) cc2420_store_msg(a,b)
#define	hal_store_buf(a,b) cc2420_store_txfifo(a,b)
#define	hal_set_tx() cc2420_set_tx()
#define	hal_set_tx_on_cca() cc2420_set_tx_on_cca()
#define	hal_set_rx() cc2420_set_rx()
#define	hal_set_sleep(a) cc2420_set_sleep(a)
#define	hal_radio_turn_on() cc2420_turn_on()
#define	hal_rssi_get() cc2420_rssi_get()
#define	hal_set_channel(a) cc2420_set_channel(a)
#define	hal_radio_get_status() cc2420_get_status()
#define	hal_radio_get_FSM() cc2420_get_FSM()
#define	hal_set_mac_short_add(a) cc2420_set_short_mac_add(a)
#define	hal_set_mac_ex_add(a) cc2420_set_ex_mac_add(a)
#define	hal_set_mac_pan_id(a) cc2420_set_mac_pan_id(a)

#endif

#endif
